@@ -4,7 +4,7 @@ from django.core.files.base import ContentFile
 from django.test import TestCase, RequestFactory
 import htmls
 from cradmin_legacy.python2_compatibility import mock
-from model_mommy import mommy
+from model_bakery import baker
 
 from cradmin_legacy import cradmin_testhelpers
 from cradmin_legacy.apps.cradmin_imagearchive import cradminviews
@@ -78,14 +78,14 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
     def test_no_archive_images(self):
         mockresponse = self.mock_http200_getrequest_htmls(
             requestuser=create_user('testuser'),
-            cradmin_role=mommy.make('cradmin_legacy_testapp.TstRole'))
+            cradmin_role=baker.make('cradmin_legacy_testapp.TstRole'))
         self.assertEqual(
             mockresponse.selector.one('#objecttableview-no-items-message').alltext_normalized,
             'No archive images')
 
     def test_single_archive_image_sanity(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        baker.make('cradmin_imagearchive.ArchiveImage',
                    name='Test image', description='',
                    role=testrole)
         mockresponse = self.mock_http200_getrequest_htmls(
@@ -95,9 +95,9 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
         self.assertEqual(mockresponse.selector.count('#objecttableview-table tbody tr'), 1)
 
     def test_only_owned_by_role(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        other_role = mommy.make('cradmin_legacy_testapp.TstRole')
-        mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        other_role = baker.make('cradmin_legacy_testapp.TstRole')
+        baker.make('cradmin_imagearchive.ArchiveImage',
                    name='Test image', description='',
                    role=other_role)
         mockresponse = self.mock_http200_getrequest_htmls(
@@ -106,8 +106,8 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
         self.assertTrue(mockresponse.selector.exists('#objecttableview-no-items-message'))
 
     def test_render_single_archive_image_no_description(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        baker.make('cradmin_imagearchive.ArchiveImage',
                    name='Test image', description='',
                    role=testrole)
         mockresponse = self.mock_http200_getrequest_htmls(
@@ -123,8 +123,8 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             'Set a description')
 
     def test_render_single_archive_image_has_description(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        baker.make('cradmin_imagearchive.ArchiveImage',
                    name='Test image', description='Test description',
                    role=testrole)
         mockresponse = self.mock_http200_getrequest_htmls(
@@ -140,7 +140,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             'Edit description')
 
     def test_uploadform_get_render(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         mockresponse = self.mock_http200_getrequest_htmls(
             requestuser=create_user('testuser'),
             cradmin_role=testrole)
@@ -151,7 +151,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
 
     def test_uploadform_post_no_filecollectionid(self):
         self.assertEqual(ArchiveImage.objects.count(), 0)
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         mockresponse = self.mock_http200_postrequest_htmls(
             requestuser=create_user('testuser'),
             cradmin_role=testrole)
@@ -169,7 +169,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         cradmin_app = mock.MagicMock()
         cradmin_app.reverse_appurl.return_value = '/success'
         self.assertEqual(ArchiveImage.objects.count(), 0)
@@ -199,7 +199,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         self.mock_http302_postrequest(
             requestuser=testuser,
             cradmin_role=testrole,
@@ -224,7 +224,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             filename='testfile2.png')
         temporaryfile.file.save('testfile2.png', ContentFile(testimage2))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         cradmin_app = mock.MagicMock()
         cradmin_app.reverse_appurl.return_value = '/success'
 
@@ -259,7 +259,7 @@ class TestArchiveImagesListView(TestCase, cradmin_testhelpers.TestCaseMixin):
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         self.mock_http302_postrequest(
             requestuser=testuser,
             cradmin_role=testrole,
@@ -278,14 +278,14 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
     def test_no_archive_images(self):
         mockresponse = self.mock_http200_getrequest_htmls(
             requestuser=create_user('testuser'),
-            cradmin_role=mommy.make('cradmin_legacy_testapp.TstRole'))
+            cradmin_role=baker.make('cradmin_legacy_testapp.TstRole'))
         self.assertEqual(
             mockresponse.selector.one('#objecttableview-no-items-message').alltext_normalized,
             'No archive images')
 
     def test_single_archive_image_sanity(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        archiveimage = mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        archiveimage = baker.make('cradmin_imagearchive.ArchiveImage',
                                   role=testrole)
         archiveimage.image.save('testimage.png', ContentFile(create_image(200, 100)))
 
@@ -299,9 +299,9 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
         self.assertEqual(mockresponse.selector.count('#objecttableview-table tbody tr'), 1)
 
     def test_only_owned_by_role(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        other_role = mommy.make('cradmin_legacy_testapp.TstRole')
-        mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        other_role = baker.make('cradmin_legacy_testapp.TstRole')
+        baker.make('cradmin_imagearchive.ArchiveImage',
                    name='Test image', description='',
                    role=other_role)
         mockresponse = self.mock_http200_getrequest_htmls(
@@ -310,8 +310,8 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
         self.assertTrue(mockresponse.selector.exists('#objecttableview-no-items-message'))
 
     def test_render_single_archive_image_no_description(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        archiveimage = mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        archiveimage = baker.make('cradmin_imagearchive.ArchiveImage',
                                   name='Test image', description='',
                                   role=testrole)
         archiveimage.image.save('testimage.png', ContentFile(create_image(200, 100)))
@@ -331,8 +331,8 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             'Use this')
 
     def test_render_single_archive_image_has_description(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
-        archiveimage = mommy.make('cradmin_imagearchive.ArchiveImage',
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
+        archiveimage = baker.make('cradmin_imagearchive.ArchiveImage',
                                   name='Test image', description='Test description',
                                   role=testrole)
         archiveimage.image.save('testimage.png', ContentFile(create_image(200, 100)))
@@ -352,7 +352,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             'Use this')
 
     def test_uploadform_get_render(self):
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         mockresponse = self.mock_http200_getrequest_htmls(
             requestuser=create_user('testuser'),
             cradmin_role=testrole)
@@ -362,7 +362,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
 
     def test_uploadform_post_no_filecollectionid(self):
         self.assertEqual(ArchiveImage.objects.count(), 0)
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         mockresponse = self.mock_http200_postrequest_htmls(
             requestuser=create_user('testuser'),
             cradmin_role=testrole)
@@ -380,7 +380,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         cradmin_app = mock.MagicMock()
         self.assertEqual(ArchiveImage.objects.count(), 0)
         mockresponse = self.mock_http302_postrequest(
@@ -410,7 +410,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         self.mock_http302_postrequest(
             requestuser=testuser,
             cradmin_role=testrole,
@@ -436,7 +436,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             filename='testfile2.png')
         temporaryfile.file.save('testfile2.png', ContentFile(testimage2))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         cradmin_app = mock.MagicMock()
         cradmin_app.reverse_appurl.return_value = '/success'
 
@@ -465,7 +465,7 @@ class TestArchiveImagesSingleSelectView(TestCase, cradmin_testhelpers.TestCaseMi
             filename='testfile.png')
         temporaryfile.file.save('testfile.png', ContentFile(testimage))
 
-        testrole = mommy.make('cradmin_legacy_testapp.TstRole')
+        testrole = baker.make('cradmin_legacy_testapp.TstRole')
         self.mock_http302_postrequest(
             requestuser=testuser,
             cradmin_role=testrole,
